@@ -77,7 +77,9 @@ f.scene.camera.zoom(1.2)
 
 if SAVE:
     mlab.savefig(
-        SAVE_DIR + "surface_harmonics.png", figure=f, magnification=4,
+        SAVE_DIR + "surface_harmonics.png",
+        figure=f,
+        magnification=4,
     )
 
     mlab.close()
@@ -95,6 +97,8 @@ f.scene.z_plus_view()
 
 if SAVE:
     mlab.savefig(
-        SAVE_DIR + "suhmesh.png", figure=f, magnification=6,
+        SAVE_DIR + "suhmesh.png",
+        figure=f,
+        magnification=6,
     )
     mlab.close()
